==> haskell-hspec-wai-json-0.11.0-477.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-EN7jDlCj9PxDOnDbTzGTrW
key:                  hspec-wai-json-0.11.0-EN7jDlCj9PxDOnDbTzGTrW
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  d4a914f936d946fdf31df845118cbf54
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-EN7jDlCj9PxDOnDbTzGTrW
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    aeson-qq-0.8.4-HBh8u0aSWtbGPUsdZlNJVg base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    hspec-wai-0.11.1-JSDm24FS6O98dcv2gdEmhw template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-503-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-9ZMlJo82W3q3OmSmrSApQ1
key:                  hspec-wai-json-0.11.0-9ZMlJo82W3q3OmSmrSApQ1
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  aeb1f79c4c4f583b8376ce05febe7404
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-9ZMlJo82W3q3OmSmrSApQ1
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-qq-0.8.4-BQMj5vJTtVl1e5F2KerQSt base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    hspec-wai-0.11.1-9eI9vF5lHNlLBjlPLqaKCJ template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
